@@ -706,22 +706,11 @@ class FirewallDConfig(slip.dbus.service.Object):
         self.accessCheck(sender)
 
         if interface_name == config.dbus.DBUS_INTERFACE_CONFIG:
-            if property_name in [ "MinimalMark", "CleanupOnExit", "Lockdown",
+            if property_name in [ "CleanupOnExit", "Lockdown",
                                   "IPv6_rpfilter", "IndividualCalls",
-                                  "LogDenied", "AutomaticHelpers",
+                                  "LogDenied",
                                   "FirewallBackend", "FlushAllOnReload",
                                   "RFC3964_IPv4", "AllowZoneDrifting" ]:
-                if property_name == "MinimalMark":
-                    try:
-                        int(new_value)
-                    except ValueError:
-                        raise FirewallError(errors.INVALID_MARK, new_value)
-                try:
-                    new_value = str(new_value)
-                except:
-                    raise FirewallError(errors.INVALID_VALUE,
-                                        "'%s' for %s" % \
-                                        (new_value, property_name))
                 if property_name in [ "CleanupOnExit", "Lockdown",
                                       "IPv6_rpfilter", "IndividualCalls" ]:
                     if new_value.lower() not in [ "yes", "no",
@@ -734,11 +723,6 @@ class FirewallDConfig(slip.dbus.service.Object):
                         raise FirewallError(errors.INVALID_VALUE,
                                             "'%s' for %s" % \
                                             (new_value, property_name))
-                if property_name == "AutomaticHelpers":
-                    if new_value not in config.AUTOMATIC_HELPERS_VALUES:
-                        raise FirewallError(errors.INVALID_VALUE,
-                                            "'%s' for %s" % \
-                                            (new_value, property_name))
                 if property_name == "FirewallBackend":
                     if new_value not in config.FIREWALL_BACKEND_VALUES:
                         raise FirewallError(errors.INVALID_VALUE,
@@ -764,6 +748,9 @@ class FirewallDConfig(slip.dbus.service.Object):
                 self.config.get_firewalld_conf().write()
                 self.PropertiesChanged(interface_name,
                                        { property_name: new_value }, [ ])
+            elif property_name in ["MinimalMark", "AutomaticHelpers"]:
+                # deprecated fields. Ignore setting them.
+                pass
             else:
                 raise dbus.exceptions.DBusException(
                     "org.freedesktop.DBus.Error.InvalidArgs: "
